commandline

package
v0.0.12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 8, 2025 License: Unlicense Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Adds

func Adds() *cobra.Command

func CmdAdd added in v0.0.4

func CmdAdd() *cobra.Command

TODO: add flag to delete file after adding. TODO: rename -f file flag to -p path ? TODO: possible to check for item existence before api request?

func CmdCobra added in v0.0.4

func CmdCobra()

func CmdRemove added in v0.0.4

func CmdRemove() *cobra.Command

TODO: remove via filter?

func Config added in v0.0.11

func Config() *cobra.Command

func Folder added in v0.0.10

func Folder() *cobra.Command

func List

func List() *cobra.Command

List creates the "list" command.

func RecentLibraries added in v0.0.11

func RecentLibraries() *cobra.Command

func Reveal

func Reveal() *cobra.Command

func Shutdown

func Shutdown() *cobra.Command

func SubCmdApi added in v0.0.12

func SubCmdApi() *cobra.Command

func Switch

func Switch() *cobra.Command

TODO: add nest list available or nest list list or nest list show or nest list libs or nest list libraries to show libraries available to switch to (print)

Types

This section is empty.

Jump to